@@ -9,7 +9,7 @@ use utf8;
 use Carp;
 use JSON::MaybeXS qw/JSON/;
 
-our $VERSION = "1.003000";
+our $VERSION = "1.004000";
 $VERSION = eval $VERSION;
 
 =encoding utf-8
@@ -325,6 +325,16 @@ a translation exists, otherwise no traslation occurs). Any other parameters
 passed to the method (C<@args>) are injected to the placeholders in the string
 (if present).
 
+If an argument is an array ref, it'll be replaced with
+a recursive call to C<loc> with its elements, with the C<$lang>
+argument automatically added.  In other
+words, the following two statements are equivalent:
+
+    print $w->loc("I'm using %1", 'he', $w->loc('Linux', 'he'));
+    # same result as
+    print $w->loc("I'm using %1", 'he', [ 'Linux' ]);
+
+
 =cut
 
 sub loc {
@@ -333,17 +343,46 @@ sub loc {
 	return unless defined $msg; # undef strings are passed back as-is
 	return $msg unless $lang;
 
+    @args = map {
+        ref $_ ne 'ARRAY' ?  $_ : do {
+            my @args = @$_;
+            splice @args, 1, 0, $lang;
+            $self->loc( @args );
+        }
+    } @args;
+
 	my $ret = $self->{locales}->{$msg} && $self->{locales}->{$msg}->{$lang} ? $self->{locales}->{$msg}->{$lang} : $msg;
 
-	if (scalar @args) {
-		for (my $i = 1; $i <= scalar @args; $i++) {
-			$ret =~ s/%$i/$args[$i-1]/g;
-		}
-	}
+    $ret =~ s/%(\d+)/$args[$1-1]/g;
 
 	return $ret;
 }
 
+=head2 loc_for( $lang )
+
+Returns a function ref that is like C<loc>, but with the C<$lang> curried away.
+
+    use Locale::Wolowitz;
+
+    my $w = Locale::Wolowitz->new( './i18n' );
+
+    my $french_loc  = $w->loc_for('fr');
+    my $german_loc  = $w->loc_for('de');
+
+    print $french_loc->('Welcome!'); # equivalent to $w->loc( 'Welcome!', 'fr' )
+
+=cut
+
+sub loc_for {
+    my( $self, $lang ) = @_;
+
+    return sub {
+        my $text = shift;
+        $self->loc( $text, $lang, @_ );
+    };
+}
+
+
 =head1 DIAGNOSTICS
 
 The following exceptions are thrown by this module:
@@ -377,7 +416,7 @@ will include both the name of the file, and the actual reason for the failure.
 =back
 
 =head1 CONFIGURATION AND ENVIRONMENT
-  
+
 C<Locale::Wolowitz> requires no configuration files or environment variables.
 
 =head1 DEPENDENCIES
@@ -413,11 +452,11 @@ Ido Perlmuter <ido@ido50.net>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2010-2015, Ido Perlmuter C<< ido@ido50.net >>.
+Copyright (c) 2010-2017, Ido Perlmuter C<< ido@ido50.net >>.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself, either version
-5.8.1 or any later version. See L<perlartistic|perlartistic> 
+5.8.1 or any later version. See L<perlartistic|perlartistic>
 and L<perlgpl|perlgpl>.
 
 The full text of the license can be found in the
